@@ -190,7 +190,7 @@ class Save:
     def createdb(self):
         conn = sqlite3.connect(self.savepath)
         c = conn.cursor()
-        c.execute('''CREATE TABLE fc2
+        c.execute('''CREATE TABLE movie
               (id             TEXT PRIMARY KEY ,
                date           CHAR(10),
                runtime        INTEGER DEFAULT 0,
@@ -220,7 +220,7 @@ class Save:
         if not os.path.exists(self.savepath):self.createdb()
         conn = sqlite3.connect(self.savepath)
         cursor = conn.cursor()
-        sqltext = f"INSERT INTO fc2 (id,date,runtime,javdblink,director,directorlink,studio,studiolink,tag,taglink,genres,genreslink,actors,actorslink,rating,ratingnum,smallimage,bigimage,previewimages,magnets) " \
+        sqltext = f"INSERT INTO movie (id,date,runtime,javdblink,director,directorlink,studio,studiolink,tag,taglink,genres,genreslink,actors,actorslink,rating,ratingnum,smallimage,bigimage,previewimages,magnets) " \
                   f"VALUES ('{detailinfo['id']}', '{detailinfo['date']}', {detailinfo['runtime']}, '{detailinfo['javdblink']}','{detailinfo['director']}','{detailinfo['directorlink']}','{detailinfo['studio']}','{detailinfo['studiolink']}','{detailinfo['tag']}','{detailinfo['taglink']}','{detailinfo['genres']}','{detailinfo['genreslink']}','{detailinfo['actors']}','{detailinfo['actorslink']}',{detailinfo['rating']}, {detailinfo['ratingnum']},'{detailinfo['smallimage']}','{detailinfo['bigimage']}','{detailinfo['previewimages']}','{detailinfo['magnets']}') " \
                   f"ON CONFLICT(id) DO UPDATE SET date = '{detailinfo['date']}',runtime={detailinfo['runtime']},javdblink='{detailinfo['javdblink']}',director='{detailinfo['director']}',directorlink='{detailinfo['directorlink']}',studio='{detailinfo['studio']}',studiolink='{detailinfo['studiolink']}',tag='{detailinfo['tag']}',taglink='{detailinfo['taglink']}',genres='{detailinfo['genres']}',genreslink='{detailinfo['genreslink']}',actors='{detailinfo['actors']}',actorslink='{detailinfo['actorslink']}',rating={detailinfo['rating']},ratingnum={detailinfo['ratingnum']},smallimage='{detailinfo['smallimage']}',bigimage='{detailinfo['bigimage']}',previewimages='{detailinfo['previewimages']}',magnets='{detailinfo['magnets']}';"
         cursor.execute(sqltext)
